package restricted

  1. Overview
  2. Docs

Module Restricted.PathAccessSource

Path Access abstraction: OpenBSD: unveil(2)ndex-pledge man:unveil(2) Linux: landlock(7)ndex-seccomp man:landlock(7)

Sourcetype t = {
  1. permissions : Restricted__.Types.PathPermission.t list;
  2. path : string;
    (*

    path:

    • OpenBSD: a path that is a directory will enable all filesystem access underneath path using permissions if and only if no more specific matching PathAccess exists later. Directories are remembered at the time of a call to unveil(). This means that a directory that is removed and recreated after a call to unveil() will appear to not exist
    • Linux: a path that is a directory will enable all filesystem access underneath path
    *)
}